pub struct BindingContext { /* private fields */ }Expand description
Represents a binding context. Binding contexts are
per-thread structures, used to track which bindings
have been accessed in a computed() function.
Implementations
Sourceimpl BindingContext
impl BindingContext
Sourcepub fn current() -> Option<BindingContext>
pub fn current() -> Option<BindingContext>
Gets the active binding context
Sourcepub fn panic_if_in_binding_context(msg: &str)
pub fn panic_if_in_binding_context(msg: &str)
Panics if we’re trying to create a binding, with a particular message
Sourcepub fn bind<TResult, TFn>(to_do: TFn) -> (TResult, BindingDependencies)where
TFn: FnOnce() -> TResult,
pub fn bind<TResult, TFn>(to_do: TFn) -> (TResult, BindingDependencies)where
TFn: FnOnce() -> TResult,
Executes a function in a new binding context
Sourcepub fn out_of_context<TResult, TFn>(to_do: TFn) -> TResultwhere
TFn: FnOnce() -> TResult,
pub fn out_of_context<TResult, TFn>(to_do: TFn) -> TResultwhere
TFn: FnOnce() -> TResult,
Performs an action outside of the binding context (dependencies will not be tracked for anything the supplied function does)
Sourcepub fn add_dependency<TChangeable: Changeable + 'static>(
dependency: TChangeable,
)
pub fn add_dependency<TChangeable: Changeable + 'static>( dependency: TChangeable, )
Adds a dependency to the current context (if one is found)