BindRef

Struct BindRef 

pub struct BindRef<Target> { /* private fields */ }
A BindRef references another binding without needing to know precisely what kind of binding it is. It is read-only, so mostly useful for passing a binding around, particularly for computed bindings. Create one with BindRef::from(binding).

Cloning a BindRef will create another reference to the same binding.

Implementations

Source

impl<TValue> BindRef<TValue>

pub fn new<Binding>(binding: &Binding) -> BindRef<TValue>
where Binding: 'static + Clone + Bound<Value = TValue>,

Creates a new BindRef from a reference to an existing binding

pub fn from_arc<Binding>(binding_ref: Arc<Binding>) -> BindRef<TValue>
where Binding: 'static + Bound<Value = TValue>,

Creates a new BindRef from an existing binding