RopeBinding

Struct RopeBinding 

pub struct RopeBinding<Cell, Attribute>
where Cell: 'static + Send + Unpin + Clone + PartialEq, Attribute: 'static + Send + Sync + Unpin + Clone + PartialEq + Default,
{ /* private fields */ }
A rope binding binds a vector of cells and attributes

It’s also possible to use a normal Binding<Vec<_>> for this purpose. A rope binding has a couple of advantages though: it can handle very large collections of items and it can notify only the relevant changes instead of always notifying the entire structure.

Rope bindings are ideal for representing text areas in user interfaces, but can be used for any collection data structure.

Implementations

Source

impl<Cell, Attribute> RopeBinding<Cell, Attribute>
where Cell: 'static + Send + Unpin + Clone + PartialEq, Attribute: 'static + Send + Sync + Clone + Unpin + PartialEq + Default,

pub fn from_mutable(binding: &RopeBindingMut<Cell, Attribute>) -> Self

Generates a rope binding by tracking a mutable binding

pub fn from_stream<S>(stream: S) -> Self
where S: 'static + Stream<Item = RopeAction<Cell, Attribute>> + Unpin + Send,

Creates a new rope binding from a stream of changes

pub fn computed<TFn, TValueIter>(calculate_value: TFn) -> Self
where TFn: 'static + Send + Fn() -> TValueIter, TValueIter: IntoIterator<Item = Cell>,

Creates a rope binding that entirely replaces its set of cells by following a computed value (the attributes will always have their default values when using this method)

pub fn len(&self) -> usize

Returns the number of cells in this rope

pub fn read_cells<'a>( &'a self, range: Range<usize>, ) -> impl 'a + Iterator<Item = Cell>

Reads the cell values for a range in this rope

pub fn read_attributes<'a>(&'a self, pos: usize) -> (Attribute, Range<usize>)

Returns the attributes set at the specified location and their extent

Source

impl<Cell, Attribute> RopeBinding<Cell, Attribute>
where Cell: 'static + Send + Unpin + Clone + PartialEq + Hash + Ord + Eq, Attribute: 'static + Send + Sync + Clone + Unpin + PartialEq + Default,

pub fn computed_difference<TFn: 'static + Send + Fn() -> TValueIter, TValueIter: IntoIterator<Item = Cell>>( calculate_value: TFn, ) -> Self

Similar to computed, but instead of always replacing the entire rope, replaces only the sections that are different between the two values.

This currently stores up to three copies of the list of cells (generally only two, but up to three while computing diffs). This is not efficient for sending edits, but useful when they’re not easily known. Use RopeBindingMut to send edits as they arrive instead.

In spite of this, this is still useful when updating something like a user interface where only the changes should be sent to the user, or for generating edit lists when the data source is not already formatted in a suitable form.