Trait flo_binding::Notifiable [−][src]
Trait implemented by items with dependencies that need to be notified when they have changed
Required methods
fn mark_as_changed(&self)[src]
Indicates that a dependency of this object has changed
Implementations on Foreign Types
impl<Value, TFn> Notifiable for Weak<Mutex<ComputedBindingCore<Value, TFn>>> where
Value: 'static + Clone + Send,
TFn: 'static + Send + Sync + Fn() -> Value, [src]
Value: 'static + Clone + Send,
TFn: 'static + Send + Sync + Fn() -> Value,
The weak reference to a core is generated in monitor_changes: this specifies what happens when a
notification is generated for such a reference.