pub struct BindRef<Target> { /* private fields */ }Expand description
A BindRef references another binding without needing to know precisely
what kind of binding it is. It is read-only, so mostly useful for passing
a binding around, particularly for computed bindings. Create one with
BindRef::from(binding).
Cloning a BindRef will create another reference to the same binding.
Implementations