Struct flo_binding::BindRef [−][src]
A BindRef references another binding without needing to know precisely
what kind of binding it is. It is read-only, so mostly useful for passing
a binding around, particularly for computed bindings. Create one with
BindRef::from(binding).
Cloning a BindRef will create another reference to the same binding.
Implementations
impl<Value> BindRef<Value>[src]
pub fn new<Binding: 'static + Clone + Bound<Value>>(
binding: &Binding
) -> BindRef<Value>[src]
binding: &Binding
) -> BindRef<Value>
Creates a new BindRef from a reference to an existing binding
pub fn from_arc<Binding: 'static + Bound<Value>>(
binding_ref: Arc<Binding>
) -> BindRef<Value>[src]
binding_ref: Arc<Binding>
) -> BindRef<Value>
Creates a new BindRef from an existing binding