pub struct NotifyWatcher<TValueFn, TValue>where
TValueFn: Fn() -> TValue,{ /* private fields */ }Expand description
Watcher that calls a ‘notify’ method whenever its core value changes
Implementations
Sourceimpl<TValueFn, TValue> NotifyWatcher<TValueFn, TValue>where
TValueFn: Fn() -> TValue,
impl<TValueFn, TValue> NotifyWatcher<TValueFn, TValue>where
TValueFn: Fn() -> TValue,
Sourcepub fn new(
get_value: TValueFn,
to_notify: Arc<dyn Notifiable>,
) -> (NotifyWatcher<TValueFn, TValue>, ReleasableNotifiable)
pub fn new( get_value: TValueFn, to_notify: Arc<dyn Notifiable>, ) -> (NotifyWatcher<TValueFn, TValue>, ReleasableNotifiable)
Creates a new notify watcher
The return value is the watcher and the function to call to indicate that a change has happened in the
underlying data store (the corresponding to_notify notification will be fired only if get() has been
called since the last update)